==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/WebApplicationFirewallOperator.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The operator to be matched.
 */
public enum class WebApplicationFirewallOperator(
    public val javaValue: com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator> {
    IPMatch(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.IPMatch),
    Equal(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.Equal),
    Contains(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.Contains),
    LessThan(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.LessThan),
    GreaterThan(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.GreaterThan),
    LessThanOrEqual(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.LessThanOrEqual),
    GreaterThanOrEqual(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.GreaterThanOrEqual),
    BeginsWith(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.BeginsWith),
    EndsWith(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.EndsWith),
    Regex(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.Regex),
    GeoMatch(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.GeoMatch),
    Any(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.Any),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator):
            WebApplicationFirewallOperator =
            WebApplicationFirewallOperator.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/WebApplicationFirewallOperator.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The operator to be matched.
 */
public enum class WebApplicationFirewallOperator(
    public val javaValue: com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator> {
    IPMatch(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.IPMatch),
    Equal(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.Equal),
    Contains(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.Contains),
    LessThan(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.LessThan),
    GreaterThan(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.GreaterThan),
    LessThanOrEqual(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.LessThanOrEqual),
    GreaterThanOrEqual(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.GreaterThanOrEqual),
    BeginsWith(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.BeginsWith),
    EndsWith(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.EndsWith),
    Regex(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.Regex),
    GeoMatch(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.GeoMatch),
    Any(com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator.Any),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.WebApplicationFirewallOperator): WebApplicationFirewallOperator =
            WebApplicationFirewallOperator.values().first { it.javaValue == javaType }
    }
}
